@@ -6,7 +6,7 @@ opendir(my $dir, '.') or die "Could not opendir(.) - $!";
 
 while(my $file = readdir($dir))
 {
-  next  if($file !~ /\.t$/ || $file =~ /subclass|warning|pod/);
+  next  if($file !~ /\.t$/ || $file =~ /subclass|warning|pod|storable|pk-columns/);
 
   my $new_file = "subclass-$file";
 
@@ -15,8 +15,6 @@ while(my $file = readdir($dir))
 
   while(<$old>)
   {
-    s/'Rose::DB::Generic'/'My::DB2::__RoseDBPrivate__::Rose::DB::Generic'/;
-
     # I know, I know...
     unless(/^\s*use_ok|Rose::DB::(\w+)|->isa\(/)
     {
